@@ -7,14 +7,7 @@
  * modification of this software and in all copies of the supporting
  * documentation for such software.
  *
- * This software is subject to United States export controls.  You may
- * not export it, in whole or in part, or cause or allow such export,
- * through act or omission, without prior authorization from the United
- * States government and written permission from AT&T.  In particular,
- * you may not make any part of this software available for general or
- * unrestricted distribution to others, nor may you disclose this software
- * to persons other than citizens and permanent residents of the United
- * States and Canada. 
+ * This software is subject to United States export controls.
  *
  * THIS SOFTWARE IS BEING PROVIDED "AS IS", WITHOUT ANY EXPRESS OR IMPLIED
  * WARRANTY.  IN PARTICULAR, NEITHER THE AUTHORS NOR AT&T MAKE ANY
@@ -98,7 +91,9 @@ main(argc,argv)
 	}
 	copykey(&k,&kt);
 	genmasks(&kt);
-	while (gets(estr) != NULL) {
+	while (fgets(estr, sizeof(estr), stdin) != NULL) {
+		if (estr[strlen(estr)-1] == '\n')
+			estr[strlen(estr)-1] = '\0';
 		cstr=decryptname(&kt,estr);
 		if (verb)
 			printf("%s -> ",estr);
